==> moodle-3.1.2.zip: moodle/mod/workshop/form/numerrors/lang/en/workshopform_numerrors.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'workshopform_numerrors', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package    workshopform_numerrors
 * @copyright  2009 David Mudrak <david@moodle.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['addmoredimensions'] = 'Blanks for {$a} more assertions';
$string['configgrade0'] = 'The default word describing the negative assessment of an assertion.';
$string['configgrade1'] = 'The default word describing the positive assessment of an assertion.';
$string['dimensioncomment'] = 'Comment';
$string['dimensioncommentfor'] = 'Comment for {$a}';
$string['dimensiondescription'] = 'Description';
$string['dimensiongrade'] = 'Grade';
$string['dimensionnumber'] = 'Assertion {$a}';
$string['dimensionweight'] = 'Weight';
$string['grademapping'] = 'Grade mapping table';
$string['grade0'] = 'Word for the error';
$string['grade0default'] = 'No';
$string['grade1'] = 'Word for the success';
$string['grade1default'] = 'Yes';
$string['maperror'] = 'Weighted number of errors is less than or equals';
$string['mapgrade'] = 'Grade for submission';
$string['percents'] = '{$a} %';
$string['pluginname'] = 'Number of errors';

==> moodle-3.4.8.zip: moodle/mod/workshop/form/numerrors/lang/en/workshopform_numerrors.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'workshopform_numerrors', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package    workshopform_numerrors
 * @copyright  2009 David Mudrak <david@moodle.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['addmoredimensions'] = 'Blanks for {$a} more assertions';
$string['configgrade0'] = 'The default word describing the negative assessment of an assertion.';
$string['configgrade1'] = 'The default word describing the positive assessment of an assertion.';
$string['dimensioncommentfor'] = 'Comment for {$a}';
$string['dimensiondescription'] = 'Description';
$string['dimensiongrade'] = 'Grade';
$string['dimensionnumber'] = 'Assertion {$a}';
$string['dimensionweight'] = 'Weight';
$string['grademapping'] = 'Grade mapping table';
$string['grade0'] = 'Word for the error';
$string['grade0default'] = 'No';
$string['grade1'] = 'Word for the success';
$string['grade1default'] = 'Yes';
$string['maperror'] = 'Weighted number of errors is less than or equals';
$string['mapgrade'] = 'Grade for submission';
$string['percents'] = '{$a}%';
$string['pluginname'] = 'Number of errors';
$string['privacy:metadata'] = 'The Number of errors plugin only stores the details of the assessment form. Actual personal data of how the form has been filled are stored by the Workshop module itself and are attached to exported assessments.';
$string['privacy:export:metadata:map'] = 'If the weighted number of errors reaches {$a->nonegative} then the grade is {$a->grade} percents.';

// Deprecated since Moodle 3.1.
$string['dimensioncomment'] = 'Comment';
